@@ -1,6 +1,5 @@
 #!/usr/bin/env python3
-"""
-Article MCP 模块执行入口
+"""Article MCP 模块执行入口
 支持 python -m article_mcp 命令
 """
 
